import config from '@/config'
import storage from '@/utils/storage'
import constant from '@/utils/constant'
import { login, logout, getInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'

const baseUrl = config.baseUrl

const user = {
  state: {
    token: getToken(),
    name: storage.get(constant.name),
    avatar: storage.get(constant.avatar),
    roles: storage.get(constant.roles),
	deptId: storage.get(constant.deptId),
    deptName: storage.get(constant.deptName),
    permissions: storage.get(constant.permissions),
	autologin:storage.get(constant.autologin),
	userId: storage.get(constant.userId),
	phonenumber: storage.get(constant.phonenumber),
	initFace: storage.get(constant.initFace),
	userType: storage.get(constant.userType),
	wgtcode:storage.get(constant.wgtcode)
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
      storage.set(constant.name, name)
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
      storage.set(constant.avatar, avatar)
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
      storage.set(constant.roles, roles)
    },
	SET_DEPID: (state, deptId) => {
	  state.deptId = deptId
	  storage.set(constant.deptId, deptId)
	},
	SET_DEPTNAME: (state, deptName) => {
	  state.deptName = deptName
	  storage.set(constant.deptName, deptName)
	},
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
      storage.set(constant.permissions, permissions)
    },
	SET_AUTOLOGIN: (state, autologin) => {
	  state.autologin = autologin
	  storage.set(constant.autologin, autologin)
	},
	SET_USERID: (state, userId) => {
	  state.userId = userId
	  storage.set(constant.userId, userId) 
	},
	SET_PHONENUMBER: (state, phonenumber) => {
	  state.phonenumber = phonenumber
	  storage.set(constant.phonenumber, phonenumber)
	},
	SET_INITFACE: (state, initFace) => {
	  state.initFace = initFace
	  storage.set(constant.initFace, initFace)
	},
	SET_USERTYPE: (state, userType) => {
	  state.userType = userType
	  storage.set(constant.userType, userType)
	},
	SET_WGTCODE: (state, wgtcode) => {
	  state.wgtcode = wgtcode
	  storage.set(constant.wgtcode, wgtcode)
	},
  },

  actions: {
	// 版本号
	SetwgtFn({ commit}, code ){
		commit('SET_WGTCODE',code)
	},
	//修改认证状态
	checkInitFace({commit},data){
		commit('SET_INITFACE', data)
	},
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password =userInfo.password
      const code = userInfo.code
	  const type = userInfo.type
      const uuid = userInfo.uuid
	  const strfrom = userInfo.strfrom||""
      return new Promise((resolve, reject) => {
        login(username, password, code,type, uuid).then(res => {
          setToken(res.token)
          commit('SET_TOKEN', res.token)
		  commit('SET_AUTOLOGIN',true)
          resolve()
        }).catch(error => {
			if(error==500&&strfrom=='request'){
				uni.hideLoading()
				// 清空数据
				uni.showModal({
				  title: '提示',
				  content: '登录状态已过期，您可以继续留在该页面，或者重新登录?',
				  cancelText: '取消',
				  confirmText: '确定',
				  success: function(res) { 
				    if (res.confirm) {
						commit('SET_TOKEN', '')
						commit('SET_ROLES', [])
						commit('SET_PERMISSIONS', [])
						removeToken()
						storage.clean()
				      uni.reLaunch({ url: '/pages/login' })
				    }else{
						commit('SET_AUTOLOGIN',false)
					}
				  }
				})
			}
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          const user = res.user
          const avatar = (user == null || user.avatar == "" || user.avatar == null) ? require("@/static/images/profile.jpg") : baseUrl + user.avatar
          const username = (user == null || user.userName == "" || user.userName == null) ? "" : user.userName
         const userId = (user == null || user.userId == "" || user.userId == null) ? "" : user.userId
         const phonenumber = (user == null || user.phonenumber == "" || user.phonenumber == null) ? "" : user.phonenumber
         const initFace = (user == null || user.initFace == "" || user.initFace == null) ? "" : user.initFace
         const userType = (user == null || user.userType == "" || user.userType == null) ? "" : user.userType
		const deptId = (user == null || user.deptId == "" || user.deptId == null) ? "" : user.deptId
		const deptName = (user == null ||user.dept==null|| user.dept == ""||user.dept.deptName == "" || user.dept.deptName == null) ? "" : user.dept.deptName
		
			// var roleName=[]	
			// if(user&&user.roles&&user.roles.length){
			// 	user.roles.forEach(ite=>{
			// 		if(ite.roleName){
			// 			roleName.push(ite.roleName)
			// 		}
			// 	})
			// }
		  if (res.roles && res.roles.length > 0) {
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
		   commit('SET_DEPID', deptId)
			commit('SET_DEPTNAME', deptName)
          commit('SET_NAME', username)
          commit('SET_AVATAR', avatar)
		  commit('SET_USERID', userId)
		  commit('SET_PHONENUMBER', phonenumber)
		  commit('SET_INITFACE', initFace)
		  commit('SET_USERTYPE', userType)
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          removeToken()
          storage.clean()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    }
  }
}

export default user
